@@ -15,8 +15,6 @@ from inspect import ismethoddescriptor
 from inspect import isroutine
 from logging import getLogger
 
-__all__ = 'weave', 'Aspect', 'Proceed', 'Return', 'ALL_METHODS', 'NORMAL_METHODS'
-
 try:
     import __builtin__
 except ImportError:
@@ -27,6 +25,8 @@ try:
 except ImportError:
     ClassType = type
 
+__all__ = 'weave', 'Aspect', 'Proceed', 'Return', 'ALL_METHODS', 'NORMAL_METHODS'
+
 logger = getLogger(__name__)
 
 PY3 = sys.version_info[0] == 3
@@ -100,14 +100,20 @@ class Return(object):
         self.value = value
 
 
-class Yield(object):
-    """
-    Instructs the Aspect to yield a value.
-    """
-    __slots__ = 'value',
-
-    def __init__(self, value):
-        self.value = value
+def mimic(wrapper, func):
+    try:
+        wrapper.__name__ = func.__name__
+    except (TypeError, AttributeError):
+        pass
+    try:
+        wrapper.__module__ = func.__module__
+    except (TypeError, AttributeError):
+        pass
+    try:
+        wrapper.__doc__ = func.__doc__
+    except (TypeError, AttributeError):
+        pass
+    return wrapper
 
 
 class Aspect(object):
@@ -115,12 +121,12 @@ class Aspect(object):
     Container for the advice yielding generator. Can be used as a decorator on other function to change behavior
     according to the advices yielded from the generator.
     """
-    __slots__ = 'advise_function'
+    __slots__ = 'advising_function'
 
-    def __init__(self, advise_function):
-        if not isgeneratorfunction(advise_function):
-            raise ExpectedGeneratorFunction("advise_function %s must be a generator function." % advise_function)
-        self.advise_function = advise_function
+    def __init__(self, advising_function):
+        if not isgeneratorfunction(advising_function):
+            raise ExpectedGeneratorFunction("advising_function %s must be a generator function." % advising_function)
+        self.advising_function = advising_function
 
     def __call__(self, cutpoint_function):
         if isgeneratorfunction(cutpoint_function):
@@ -129,19 +135,18 @@ class Aspect(object):
                     'aspectlib.py3support',
                     fromlist=['decorate_advising_generator_py3']
                 ).decorate_advising_generator_py3(
-                    self.advise_function,
+                    self.advising_function,
                     cutpoint_function
                 )
             else:
-                @wraps(cutpoint_function)
                 def advising_generator_wrapper(*args, **kwargs):
-                    advisor = self.advise_function(*args, **kwargs)
+                    advisor = self.advising_function(*args, **kwargs)
                     if not isgenerator(advisor):
-                        raise ExpectedGenerator("advise_function %s did not return a generator." % self.advise_function)
+                        raise ExpectedGenerator("advising_function %s did not return a generator." % self.advising_function)
                     try:
                         advice = next(advisor)
                         while True:
-                            logger.debug('Got advice %r from %s', advice, self.advise_function)
+                            logger.debug('Got advice %r from %s', advice, self.advising_function)
                             if advice is Proceed or advice is None or isinstance(advice, Proceed):
                                 if isinstance(advice, Proceed):
                                     args = advice.args
@@ -192,25 +197,20 @@ class Aspect(object):
                                 return
                             elif isinstance(advice, Return):
                                 raise StopIteration(advice.value)
-                            elif isinstance(advice, Yield):
-                                item = yield advice.value
-                                logger.critical('sending %s (from yield %r)', item, advice.value)
-                                advice = advisor.send(item)
                             else:
                                 raise UnacceptableAdvice("Unknown advice %s" % advice)
                     finally:
                         advisor.close()
-                return advising_generator_wrapper
+                return mimic(advising_generator_wrapper, cutpoint_function)
         else:
-            @wraps(cutpoint_function)
             def advising_function_wrapper(*args, **kwargs):
-                advisor = self.advise_function(*args, **kwargs)
+                advisor = self.advising_function(*args, **kwargs)
                 if not isgenerator(advisor):
-                    raise ExpectedGenerator("advise_function %s did not return a generator." % self.advise_function)
+                    raise ExpectedGenerator("advising_function %s did not return a generator." % self.advising_function)
                 try:
                     advice = next(advisor)
                     while True:
-                        logger.debug('Got advice %r from %s', advice, self.advise_function)
+                        logger.debug('Got advice %r from %s', advice, self.advising_function)
                         if advice is Proceed or advice is None or isinstance(advice, Proceed):
                             if isinstance(advice, Proceed):
                                 args = advice.args
@@ -232,8 +232,44 @@ class Aspect(object):
                             raise UnacceptableAdvice("Unknown advice %s" % advice)
                 finally:
                     advisor.close()
-            return advising_function_wrapper
+            return mimic(advising_function_wrapper, cutpoint_function)
 
+#class Boundable(object):
+#    def __init__(self, binding=None):
+#        self.binding = binding
+#
+#    def __get__(self, instance, owner):
+#        return type(self)(instance)
+
+#class DescriptorAspect(Aspect):
+#    """
+#    Aspect that call the generator with ``instance, args, kwargs, cutpoint`` instead of the original arguments.
+#    """
+#    def __init__(self, advising_function):
+#        if not isgeneratorfunction(advising_function):
+#            raise ExpectedGeneratorFunction("advising_function %s must be a generator function." % advising_function)
+#        self.advising_function = advising_function
+#
+#    def __call__(self, cutpoint_function):
+#        wrapper = super(DescriptorAspect, self).__call__(lambda _i, args, kwargs, _f: cutpoint_function(*args, **kwargs))
+#        cutpoint_wrapping = wraps(cutpoint_function)
+#
+#        class descriptor_wrapper(object):
+#            __doc__ = cutpoint_function.__doc__
+#            __name__ = cutpoint_function.__name__
+#            __module__ = cutpoint_function.__module__
+#
+#            def __get__(self, instance, owner):
+#                print('__get__(', instance, owner, ')')
+#                return cutpoint_wrapping(lambda *args, **kwargs:
+#                    wrapper(instance, args, kwargs, cutpoint_function)
+#                )
+#
+#            def __call__(self, *args, **kwargs):
+#                print('__call__(', args, kwargs, ')')
+#                return wrapper(None, args, kwargs, cutpoint_function)
+#
+#        return descriptor_wrapper()
 
 class Fabric(object):
     pass
