@@ -6,8 +6,8 @@ import socket
 import warnings
 
 import pytest
-from process_tests import wait_for_strings
 from process_tests import dump_on_error
+from process_tests import wait_for_strings
 
 import aspectlib
 from aspectlib.test import mock
@@ -45,7 +45,7 @@ def test_mock_builtin_os():
 def test_record_warning():
     with aspectlib.weave('warnings.warn', record):
         warnings.warn('crap')
-        assert warnings.warn.calls, [(None, ('crap',) == {})]
+        assert warnings.warn.calls == [(None, ('crap',), {})]
 
 
 @pytest.mark.skipif(not hasattr(os, 'fork'), reason="os.fork not available")
@@ -65,7 +65,7 @@ def test_socket(target=socket.socket):
     buf = StringIO()
     with aspectlib.weave(target, aspectlib.debug.log(
         print_to=buf,
-        stacktrace=2,
+        stacktrace=4,
         module=False
     ), lazy=True):
         s = socket.socket()
